magneticalc.View_Menu.View_Menu

# ``magneticalc`.`View_Menu`.`View_Menu``

class documentation

`class View_Menu(QMenu):`

Constructor: `View_Menu(gui)`

View In Hierarchy

View_Menu class.

Method | `__init__` | Initializes the menu.
Method | `on_show_gauss_changed` | Gets called when the "Show Gauss instead of Tesla" option changed.
Method | `update` | Updates the menu.
Instance Variable | `checkbox_config` | Undocumented
Instance Variable | `gui` | Undocumented

def __init__(self, gui: `GUI`):

Initializes the menu.

def on_show_gauss_changed(self):

Gets called when the "Show Gauss instead of Tesla" option changed.

def update(self):

Updates the menu.

checkbox_config =

Undocumented

gui =

Undocumented